/*
 * taskview-generic.h
 *
 * TaskviewGeneric
 *
 * Copyright © 2010 Salomon Sickert
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the licence or (at
 * your option) any later version.
 *
 * See the included COPYING.LESSER file for more information.
 *
 * Authors:
 *    Salomon Sickert <sickert@in.tum.de>
 */

#ifndef __TASKVIEW_GENERIC_H__
#define __TASKVIEW_GENERIC_H__

#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define TASKVIEW_TYPE_GENERIC	(taskview_generic_get_type ())
#define TASKVIEW_GENERIC(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), TASKVIEW_TYPE_GENERIC, TaskviewGeneric))
#define TASKVIEW_GENERIC_CLASS(obj)	(G_TYPE_CHECK_CLASS_CAST ((obj), TASKVIEW_TYPE_GENERIC, TaskviewGenericClass))
#define TASKVIEW_IS_GENERIC(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TASKVIEW_TYPE_GENERIC))
#define TASKVIEW_IS_GENERIC_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), TASKVIEW_TYPE_GENERIC))
#define TASKVIEW_GENERIC_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), TASKVIEW_TYPE_GENERIC, TaskviewGenericClass))

typedef struct _TaskviewGeneric TaskviewGeneric;
typedef struct _TaskviewGenericClass TaskviewGenericClass;
typedef struct _TaskviewGenericPrivate TaskviewGenericPrivate;

struct _TaskviewGeneric
{
  GObject parent;
  TaskviewGenericPrivate *priv;
};

struct _TaskviewGenericClass
{
  GObjectClass parent_class;
  GDBusInterfaceInfo *interface;
  const GDBusInterfaceVTable *vtable;
};

GType taskview_generic_get_type (void);

typedef void (* TaskviewCallback) (TaskviewGeneric *instance,
                                   GError **error,
                                   gpointer user_data);

/* Private helper */
GHashTable * taskview_generic_get_views (void);
TaskviewGeneric  * taskview_generic_get_inst_by_id (guint id);

/* C Wrapper */

TaskviewGeneric * taskview_generic_new (void);

gchar * taskview_generic_get_icon (TaskviewGeneric *self);
gchar * taskview_generic_get_description (TaskviewGeneric *self);
gchar * taskview_generic_get_details (TaskviewGeneric *self);
gint 	  taskview_generic_get_state (TaskviewGeneric *self);
gint	  taskview_generic_get_progress (TaskviewGeneric *self);
gint 		taskview_generic_get_remaining_time (TaskviewGeneric *self);
gint64  taskview_generic_get_creation_time (TaskviewGeneric *self);
gint64  taskview_generic_get_finished_time (TaskviewGeneric *self);
gchar * taskview_generic_get_object_path (TaskviewGeneric *self);
guint 	taskview_generic_get_id (TaskviewGeneric *self);

void taskview_generic_set_icon (TaskviewGeneric *self, const gchar *icon);
void taskview_generic_set_description (TaskviewGeneric *self, const gchar *description);
void taskview_generic_set_description (TaskviewGeneric *self, const gchar *details);
void taskview_generic_set_state (TaskviewGeneric *self, gint state);
void taskview_generic_set_progress (TaskviewGeneric *self, gint progress);
void taskview_generic_set_remaining_time (TaskviewGeneric *self, gint remaining_time);
void taskview_generic_set_view_callback (TaskviewGeneric *self, TaskviewCallback *view);
void taskview_generic_set_resume_callback (TaskviewGeneric *self, TaskviewCallback *resume);
void taskview_generic_set_pause_callback (TaskviewGeneric *self, TaskviewCallback *pause);
void taskview_generic_set_cancel_callback (TaskviewGeneric *self, TaskviewCallback *cancel);
void taskview_generic_set_user_data (TaskviewGeneric *self, gpointer user_data);

G_END_DECLS

#endif
