/*
 * taskview-io.h
 *
 * TaskviewIO
 *
 * Copyright © 2010 Salomon Sickert
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the licence or (at
 * your option) any later version.
 *
 * See the included COPYING.LESSER file for more information.
 *
 * Authors:
 *    Salomon Sickert <sickert@in.tum.de>
 */

#ifndef __TASKVIEW_IO_H__
#define __TASKVIEW_IO_H__

#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define TASKVIEW_TYPE_IO	(taskview_io_get_type ())
#define TASKVIEW_IO(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), TASKVIEW_TYPE_IO, TaskviewIO))
#define TASKVIEW_IO_CLASS(obj)	(G_TYPE_CHECK_CLASS_CAST ((obj), TASKVIEW_TYPE_IO, TaskviewIOClass))
#define TASKVIEW_IS_IO(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TASKVIEW_TYPE_IO))
#define TASKVIEW_IS_IO_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), TASKVIEW_TYPE_IO))
#define TASKVIEW_IO_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), TASKVIEW_TYPE_IO, TaskviewIOClass))

typedef struct _TaskviewIO TaskviewIO;
typedef struct _TaskviewIOClass TaskviewIOClass;
typedef struct _TaskviewIOPrivate TaskviewIOPrivate;

struct _TaskviewIO
{
  TaskviewGeneric parent;
  TaskviewIOPrivate *priv;
};

struct _TaskviewIOClass
{
  TaskviewGenericClass parent_class;
  GDBusInterfaceInfo *interface;
  const GDBusInterfaceVTable *vtable;
};

GType taskview_io_get_type (void);

/* C Wrapper */

TaskviewIO * taskview_io_new (void);

gint 		 taskview_io_get_io_type (TaskviewIO *self);
guint    taskview_io_get_current_item (TaskviewIO *self);
GStrv    taskview_io_get_destination_uri (TaskviewIO *self);
GStrv    taskview_io_get_source_uri (TaskviewIO *self);
guint64  taskview_io_get_throughput_size (TaskviewIO *self);
guint64  taskview_io_get_total_size (TaskviewIO *self);
guint64  taskview_io_get_processed_size (TaskviewIO *self);
guint64  taskview_io_get_throughput_items (TaskviewIO *self);
guint64  taskview_io_get_total_items (TaskviewIO *self);
guint64  taskview_io_get_processed_items (TaskviewIO *self);
gboolean taskview_io_get_auto_update (TaskviewIO *self);

void taskview_io_set_io_type (TaskviewIO *self, gint value);
void taskview_io_set_current_item (TaskviewIO *self, guint value);
void taskview_io_set_destination_uri (TaskviewIO *self, const GStrv value);
void taskview_io_set_source_uri (TaskviewIO *self, const GStrv value);
void taskview_io_set_throughput_size (TaskviewIO *self, guint64 value);
void taskview_io_set_total_size (TaskviewIO *self, guint64 value);
void taskview_io_set_processed_size (TaskviewIO *self, guint64 value);
void taskview_io_set_throughput_items (TaskviewIO *self, guint64 value);
void taskview_io_set_total_items (TaskviewIO *self, guint64 value);
void taskview_io_set_processed_items (TaskviewIO *self, guint64 value);
void taskview_io_set_auto_update (TaskviewIO *self, gboolean value);

G_END_DECLS

#endif
